Struct network::testutils::builder::TestFrameworkBuilder [−][src]
pub struct TestFrameworkBuilder<Framework: TestFramework<Node>, Node: TestNode> { /* fields omitted */ }Expand description
A builder for a TestFramework implementation.
This handles making sure that nodes are unique, and that they have the channels attached to each other to send messages between each other.
Implementations
Create a new TestFrameworkBuilder, ensuring that there is a fixed number of owners.
Builds the TestFramework
Adds a TestNode of NodeType::Validator
Adds a TestNode of NodeType::ValidatorFullNode
Adds a TestNode of NodeType::PublicFullNode